pub enum VoxelFill {
Occupancy,
Count,
}Expand description
How a voxel’s value is filled from the points that fall in it.
Variants
Occupancy
1.0 if any point falls in the voxel, else 0.0.
Count
The number of points that fall in the voxel.