pub fn cloud_distances(
a: &PointCloud,
b: &PointCloud,
) -> Result<CloudDistances, SpatialError>Expand description
Computes directed NN distance statistics between a and b in both
directions with a single KD-tree per side.
pub fn cloud_distances(
a: &PointCloud,
b: &PointCloud,
) -> Result<CloudDistances, SpatialError>Computes directed NN distance statistics between a and b in both
directions with a single KD-tree per side.