pub fn detect_point_cloud_format(
path: impl AsRef<Path>,
) -> Option<PointCloudFileFormat>Expand description
Detects a point cloud format from a file path extension.
pub fn detect_point_cloud_format(
path: impl AsRef<Path>,
) -> Option<PointCloudFileFormat>Detects a point cloud format from a file path extension.