pub fn read_copc_file_in_bounds(
path: impl AsRef<Path>,
bounds: CopcBounds,
) -> Result<PointCloud, IoError>Expand description
Reads points inside a bounding box at full available detail.
pub fn read_copc_file_in_bounds(
path: impl AsRef<Path>,
bounds: CopcBounds,
) -> Result<PointCloud, IoError>Reads points inside a bounding box at full available detail.