pub fn reduce_positions(
source: &mut impl BoundedSpatialRecordSource,
) -> Result<PositionReduction, RecordsError>Expand description
Consumes a source and computes bounds and centroid without retaining chunks.
pub fn reduce_positions(
source: &mut impl BoundedSpatialRecordSource,
) -> Result<PositionReduction, RecordsError>Consumes a source and computes bounds and centroid without retaining chunks.