pub fn scale_cloud(
input: &PointCloud,
factor: f32,
) -> Result<PointCloud, SpatialError>Expand description
Uniformly scales a cloud about the origin by factor.
pub fn scale_cloud(
input: &PointCloud,
factor: f32,
) -> Result<PointCloud, SpatialError>Uniformly scales a cloud about the origin by factor.