Function swap_red_blue
pub fn swap_red_blue<T>(
input: ImageView<'_, T, 3>,
) -> Result<Image<T, 3>, VisionError>where
T: PixelComponent,Expand description
Swaps the red and blue channels of a three-channel image.
pub fn swap_red_blue<T>(
input: ImageView<'_, T, 3>,
) -> Result<Image<T, 3>, VisionError>where
T: PixelComponent,Swaps the red and blue channels of a three-channel image.