Struct AdaptiveBackgroundModel
pub struct AdaptiveBackgroundModel { /* private fields */ }Expand description
Stateful single-Gaussian grayscale background model.
Implementations
impl AdaptiveBackgroundModel
impl AdaptiveBackgroundModel
pub fn try_new(
frame: ImageView<'_, u8, 1>,
options: BackgroundModelOptions,
) -> Result<AdaptiveBackgroundModel, VisionError>
pub fn try_new( frame: ImageView<'_, u8, 1>, options: BackgroundModelOptions, ) -> Result<AdaptiveBackgroundModel, VisionError>
Initializes the model from its first frame.
pub fn apply(
&mut self,
frame: ImageView<'_, u8, 1>,
) -> Result<BackgroundUpdate, VisionError>
pub fn apply( &mut self, frame: ImageView<'_, u8, 1>, ) -> Result<BackgroundUpdate, VisionError>
Segments foreground and updates background statistics in one explicit step.
pub const fn frames_seen(&self) -> u64
pub const fn frames_seen(&self) -> u64
Returns the number of frames incorporated into the model.