Struct BinaryMask
pub struct BinaryMask { /* private fields */ }Expand description
Validated binary mask (0 background, 1 foreground).
Implementations
impl BinaryMask
impl BinaryMask
pub fn try_new(
width: usize,
height: usize,
data: Vec<u8>,
) -> Result<BinaryMask, VisionError>
pub fn try_new( width: usize, height: usize, data: Vec<u8>, ) -> Result<BinaryMask, VisionError>
Creates a mask and rejects values other than zero and one.
pub fn from_threshold(
input: ImageView<'_, f32, 1>,
threshold: f32,
) -> Result<BinaryMask, VisionError>
pub fn from_threshold( input: ImageView<'_, f32, 1>, threshold: f32, ) -> Result<BinaryMask, VisionError>
Thresholds a float score image into a binary mask.
pub fn into_image(self) -> Image<u8, 1>
pub fn into_image(self) -> Image<u8, 1>
Consumes the wrapper and returns its image.