pub struct PointCloudBuilder { /* private fields */ }Expand description
Builds point clouds field-by-field.
Implementations
Sourceimpl PointCloudBuilder
impl PointCloudBuilder
Sourcepub fn new(schema: PointSchema) -> PointCloudBuilder
pub fn new(schema: PointSchema) -> PointCloudBuilder
Creates a builder from a schema.
Sourcepub fn xyz() -> PointCloudBuilder
pub fn xyz() -> PointCloudBuilder
Creates a builder for the standard PointXYZ schema.
Sourcepub fn metadata(self, metadata: SpatialMetadata) -> PointCloudBuilder
pub fn metadata(self, metadata: SpatialMetadata) -> PointCloudBuilder
Sets spatial metadata.
Sourcepub fn push_point<I>(&mut self, values: I) -> Result<(), SpatialError>where
I: IntoIterator<Item = f32>,
pub fn push_point<I>(&mut self, values: I) -> Result<(), SpatialError>where
I: IntoIterator<Item = f32>,
Appends one point by field values in schema order.
Each field value must be a scalar convertible to the field dtype.
Sourcepub fn build(self) -> Result<PointCloud, SpatialError>
pub fn build(self) -> Result<PointCloud, SpatialError>
Builds the final point cloud.