pub struct PositionReduction {
pub point_count: u64,
pub finite_point_count: u64,
pub bounds: Option<([f64; 3], [f64; 3])>,
pub centroid: Option<[f64; 3]>,
}Expand description
Deterministic global position reduction over a bounded source.
Fields
point_count: u64Number of points observed, including non-finite positions.
finite_point_count: u64Number of positions whose three components are finite.
bounds: Option<([f64; 3], [f64; 3])>Finite inclusive bounds, or None when no finite positions exist.
centroid: Option<[f64; 3]>Mean of finite positions, or None when no finite positions exist.