pub struct RansacPlaneSegmenter { /* private fields */ }Expand description
RANSAC-based dominant plane segmenter.
Implementations
Sourceimpl RansacPlaneSegmenter
impl RansacPlaneSegmenter
Sourcepub const fn new(config: RansacPlaneConfig) -> RansacPlaneSegmenter
pub const fn new(config: RansacPlaneConfig) -> RansacPlaneSegmenter
Creates a segmenter from config.
Sourcepub const fn config(&self) -> RansacPlaneConfig
pub const fn config(&self) -> RansacPlaneConfig
Returns the segmenter config.
Sourcepub fn segment(
&self,
input: &PointCloud,
) -> Result<RansacPlaneSegmentation, SpatialError>
pub fn segment( &self, input: &PointCloud, ) -> Result<RansacPlaneSegmentation, SpatialError>
Segments the dominant plane and returns inlier/outlier clouds.
Sourcepub fn segment_with_policy(
&self,
input: &PointCloud,
policy: ExecutionPolicy,
) -> Result<RansacPlaneSegmentation, SpatialError>
pub fn segment_with_policy( &self, input: &PointCloud, policy: ExecutionPolicy, ) -> Result<RansacPlaneSegmentation, SpatialError>
Segments the dominant plane using the given execution policy.
With the segment-ransac-plane-gpu feature, ExecutionPolicy::Auto
runs hypothesis scoring on wgpu when the input meets
RansacPlaneConfig::effective_gpu_min_points. An explicit GPU policy
is strict and does not use the threshold; use Auto for fallback.
Sourcepub fn segment_with_policy_and_receipt(
&self,
input: &PointCloud,
policy: ExecutionPolicy,
) -> Result<ExecutionOutput<RansacPlaneSegmentation>, SpatialError>
pub fn segment_with_policy_and_receipt( &self, input: &PointCloud, policy: ExecutionPolicy, ) -> Result<ExecutionOutput<RansacPlaneSegmentation>, SpatialError>
Segments a plane and returns execution/transfer accounting.
Sourcepub fn extract_outliers(
&self,
input: &PointCloud,
) -> Result<PointCloud, SpatialError>
pub fn extract_outliers( &self, input: &PointCloud, ) -> Result<PointCloud, SpatialError>
Returns only the outlier cloud after removing the dominant plane.