RobustKernel

Trait RobustKernel 

pub trait RobustKernel {
    // Required methods
    fn weight(&self, residual: f64) -> f64;
    fn rho(&self, residual: f64) -> f64;
}
Robust loss kernel used by registration and estimation algorithms.

Required Methods

fn weight(&self, residual: f64) -> f64

Computes the robust weight for a residual magnitude.

fn rho(&self, residual: f64) -> f64

Computes the robust rho value for a residual magnitude.

Implementors