pub struct StatisticalOutlierRemoval { /* private fields */ }Expand description
Statistical Outlier Removal (SOR).
For each point the mean distance to its k nearest neighbors is computed.
Assuming those means are roughly Gaussian, points whose mean distance is
more than std_mul standard deviations above the global mean are dropped.
Implementations
Sourceimpl StatisticalOutlierRemoval
impl StatisticalOutlierRemoval
Sourcepub const fn new(config: StatisticalOutlierConfig) -> StatisticalOutlierRemoval
pub const fn new(config: StatisticalOutlierConfig) -> StatisticalOutlierRemoval
Creates a filter from config.
Sourcepub const fn config(&self) -> StatisticalOutlierConfig
pub const fn config(&self) -> StatisticalOutlierConfig
Returns the filter config.
Sourcepub fn keep_mask(&self, input: &PointCloud) -> Result<Vec<bool>, SpatialError>
pub fn keep_mask(&self, input: &PointCloud) -> Result<Vec<bool>, SpatialError>
Computes the keep mask without materializing the filtered cloud.